Welcome to resqpy's documentation
=================================

**resqpy** is a library for manipulating RESQML files.

.. toctree::
   :maxdepth: 3
   :caption: Documentation

   installation
   getting-started
   trademarks

API Reference
-------------

.. automodule:: resqpy


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
